@@ -27,12 +27,12 @@
 #include "timelineitem.h"
 #include "helper.h"
 
-#include <KDGantt2/KDGanttGraphicsItem>
-#include <KDGantt2/KDGanttGraphicsView>
-#include <KDGantt2/KDGanttAbstractRowController>
-#include <KDGantt2/KDGanttDateTimeGrid>
-#include <KDGantt2/KDGanttItemDelegate>
-#include <KDGantt2/KDGanttStyleOptionGanttItem>
+#include <KGantt/KGanttGraphicsItem>
+#include <KGantt/KGanttGraphicsView>
+#include <KGantt/KGanttAbstractRowController>
+#include <KGantt/KGanttDateTimeGrid>
+#include <KGantt/KGanttItemDelegate>
+#include <KGantt/KGanttStyleOptionGanttItem>
 
 #include <Akonadi/Calendar/ETMCalendar>
 #include <CalendarSupport/CollectionSelection>
@@ -58,8 +58,7 @@ using namespace EventViews;
 
 namespace EventViews
 {
-
-class RowController : public KDGantt::AbstractRowController
+class RowController : public KGantt::AbstractRowController
 {
 private:
     static const int ROW_HEIGHT;
@@ -91,9 +90,9 @@ public:
         return false;
     }
 
-    KDGantt::Span rowGeometry(const QModelIndex &idx) const Q_DECL_OVERRIDE
+    KGantt::Span rowGeometry(const QModelIndex &idx) const Q_DECL_OVERRIDE
     {
-        return KDGantt::Span(idx.row() * mRowHeight, mRowHeight);
+        return KGantt::Span(idx.row() * mRowHeight, mRowHeight);
     }
 
     int maximumItemHeight() const Q_DECL_OVERRIDE
@@ -150,20 +149,18 @@ public:
         return s;
     }
 };
-
-class GanttItemDelegate : public KDGantt::ItemDelegate
+class GanttItemDelegate : public KGantt::ItemDelegate
 {
     void paintGanttItem(QPainter *painter,
-                        const KDGantt::StyleOptionGanttItem &opt,
+                        const KGantt::StyleOptionGanttItem &opt,
                         const QModelIndex &idx) Q_DECL_OVERRIDE {
         painter->setRenderHints(QPainter::Antialiasing);
         if (!idx.isValid())
         {
             return;
         }
-
-        KDGantt::ItemType type = static_cast<KDGantt::ItemType>(
-            idx.model()->data(idx, KDGantt::ItemTypeRole).toInt());
+        KGantt::ItemType type = static_cast<KGantt::ItemType>(
+            idx.model()->data(idx, KGantt::ItemTypeRole).toInt());
 
         QString txt = idx.model()->data(idx, Qt::DisplayRole).toString();
         QRectF itemRect = opt.itemRect;
@@ -190,28 +187,33 @@ class GanttItemDelegate : public KDGantt::ItemDelegate
 
         switch (type)
         {
-        case KDGantt::TypeTask:
+        case KGantt::TypeTask:
             if (itemRect.isValid()) {
                 QRectF r = itemRect;
                 painter->drawRect(r);
-
+                bool drawText = true;
                 Qt::Alignment ta;
                 switch (opt.displayPosition) {
-                case KDGantt::StyleOptionGanttItem::Left:
+                case KGantt::StyleOptionGanttItem::Left:
                     ta = Qt::AlignLeft;
                     break;
-                case KDGantt::StyleOptionGanttItem::Right:
+                case KGantt::StyleOptionGanttItem::Right:
                     ta = Qt::AlignRight;
                     break;
-                case KDGantt::StyleOptionGanttItem::Center:
+                case KGantt::StyleOptionGanttItem::Center:
                     ta = Qt::AlignCenter;
                     break;
+                case KGantt::StyleOptionGanttItem::Hidden:
+                    drawText = false;
+                    break;
+                }
+                if (drawText) {
+                    painter->drawText(boundingRect, ta, txt);
                 }
-                painter->drawText(boundingRect, ta, txt);
             }
             break;
         default:
-            KDGantt::ItemDelegate::paintGanttItem(painter, opt, idx);
+            KGantt::ItemDelegate::paintGanttItem(painter, opt, idx);
             break;
         }
     }
@@ -230,7 +232,7 @@ TimelineView::TimelineView(QWidget *parent)
     d->mLeftView->setRootIsDecorated(false);
     d->mLeftView->setHorizontalScrollBarPolicy(Qt::ScrollBarAlwaysOff);
 
-    d->mGantt = new KDGantt::GraphicsView();
+    d->mGantt = new KGantt::GraphicsView();
     splitter->addWidget(d->mLeftView);
     splitter->addWidget(d->mGantt);
     connect(splitter, &QSplitter::splitterMoved,
@@ -242,9 +244,8 @@ TimelineView::TimelineView(QWidget *parent)
 
     d->mRowController->setModel(model);
     d->mGantt->setRowController(d->mRowController);
-
-    KDGantt::DateTimeGrid *grid = new KDGantt::DateTimeGrid;
-    grid->setScale(KDGantt::DateTimeGrid::ScaleHour);
+    KGantt::DateTimeGrid *grid = new KGantt::DateTimeGrid;
+    grid->setScale(KGantt::DateTimeGrid::ScaleHour);
     grid->setDayWidth(800);
     grid->setRowSeparators(true);
     d->mGantt->setGrid(grid);
@@ -280,9 +281,11 @@ TimelineView::TimelineView(QWidget *parent)
 #endif
     connect(model, &QStandardItemModel::itemChanged,
             d, &Private::itemChanged);
-    connect(d->mGantt, &KDGantt::GraphicsView::doubleClicked,
-            d, &Private::itemDoubleClicked);
-    connect(d->mGantt, &KDGantt::GraphicsView::activated,
+
+    //TODO FIXME doubleClicked doesn't exist PORTING KDIAGRAM
+    //connect(d->mGantt, &KGantt::GraphicsView::doubleClicked,
+    //        d, &Private::itemDoubleClicked);
+    connect(d->mGantt, &KGantt::GraphicsView::activated,
             d, &Private::itemSelected);
     d->mGantt->setContextMenuPolicy(Qt::CustomContextMenu);
     connect(d->mGantt, &QWidget::customContextMenuRequested,
@@ -329,7 +332,8 @@ void TimelineView::showDates(const QDate &start, const QDate &end, const QDate &
     d->mStartDate = start;
     d->mEndDate = end;
     d->mHintDate = QDateTime();
-    KDGantt::DateTimeGrid *grid = static_cast<KDGantt::DateTimeGrid *>(d->mGantt->grid());
+
+    KGantt::DateTimeGrid *grid = static_cast<KGantt::DateTimeGrid *>(d->mGantt->grid());
     grid->setStartDateTime(QDateTime(start));
 #if 0
     d->mGantt->setHorizonStart(QDateTime(start));
@@ -482,8 +486,8 @@ bool TimelineView::eventFilter(QObject *object, QEvent *event)
         QHelpEvent *helpEvent = static_cast<QHelpEvent *>(event);
         QGraphicsItem *item = d->mGantt->itemAt(helpEvent->pos());
         if (item) {
-            if (item->type() == KDGantt::GraphicsItem::Type) {
-                KDGantt::GraphicsItem *graphicsItem = static_cast<KDGantt::GraphicsItem *>(item);
+            if (item->type() == KGantt::GraphicsItem::Type) {
+                KGantt::GraphicsItem *graphicsItem = static_cast<KGantt::GraphicsItem *>(item);
                 const QModelIndex itemIndex = graphicsItem->index();
 
                 QStandardItemModel *itemModel =
